@@ -2,10 +2,10 @@
 
 from __future__ import absolute_import
 
-VERSION = (0, 4, 0)
+VERSION = (0, 5, 0)
 
 __version__ = ".".join(map(str, VERSION))
 __author__ = "Ask Solem"
 __contact__ = "ask@celeryproject.org"
-__homepage__ = "http://github.com/ask/celerymon/"
+__homepage__ = "http://github.com/celery/celerymon/"
 __docformat__ = "restructuredtext"
